@@ -1,19 +1,20 @@
+import { t } from '@grafana/i18n';
 import { DataQuery } from '@grafana/schema';
 import { Modal } from '@grafana/ui';
-import { t } from 'app/core/internationalization';
 
-import { queryLibraryTrackAddQuery } from './QueryLibraryAnalyticsEvents';
+import { QueryLibraryInteractions } from './QueryLibraryAnalyticsEvents';
 import { QueryTemplateForm } from './QueryTemplateForm';
 
 type Props = {
-  isOpen: boolean;
-  close: () => void;
-  onSave?: () => void;
   query?: DataQuery;
+  title?: string;
   context?: string;
+  isOpen: boolean;
+  onSave?: () => void;
+  close: () => void;
 };
 
-export function AddToQueryLibraryModal({ query, close, isOpen, context, onSave }: Props) {
+export function AddToQueryLibraryModal({ query, title, context, isOpen, onSave, close }: Props) {
   return (
     <Modal
       title={t('explore.query-template-modal.add-title', 'Add to query library')}
@@ -27,11 +28,11 @@ export function AddToQueryLibraryModal({ query, close, isOpen, context, onSave }
         onSave={(isSuccess) => {
           if (isSuccess) {
             close();
-            queryLibraryTrackAddQuery(query?.datasource?.type || '', context);
+            QueryLibraryInteractions.saveQuerySuccess();
             onSave?.();
           }
         }}
-        queryToAdd={query!}
+        templateData={{ query: query!, title }}
       />
     </Modal>
   );
